# Single Machine Infinite Bus (SMIB) System

## Overview

`SMIB.xlsx` is originally prepared by Xiaoge Huang using data in [[1]](#1).

Parameters are modified by Hantao Cui to obtain the same per-unit results as in
the textbook in the base of 100 MVA. Essentially, the power bases, `Sn`, of all
devices are converted to 100 MVA. All elements are in the same voltage level.

## References

<a id="1">[1]</a> P. W. Sauer, M. A. Pai, and J. H. Chow, Power system dynamics
and stability: with synchrophasor measurement and power system toolbox, Second
edition. Hoboken, NJ, USA: IEEE Press, Wiley, 2017.
